@@ -22,21 +22,48 @@
 
 extern crate alloc;
 
+#[cfg(feature = "tracing")]
+macro_rules! report_error_on_drop {
+    ($($tokens:tt)*) => {{
+        #[cfg(feature = "std")]
+        {
+            if std::thread::panicking() {
+                return;
+            }
+        }
+
+        tracing::error!($($tokens)*)
+    }};
+}
+
+#[cfg(all(not(feature = "tracing"), feature = "std"))]
+macro_rules! report_error_on_drop {
+    ($($tokens:tt)*) => {{
+        if std::thread::panicking() {
+            return;
+        }
+        eprintln!($($tokens)*)
+    }};
+}
+
+#[cfg(all(not(feature = "tracing"), not(feature = "std")))]
+macro_rules! report_error_on_drop {
+    ($($tokens:tt)*) => {{
+        panic!($($tokens)*)
+    }};
+}
+
 mod allocator;
 mod block;
 mod buddy;
 mod config;
 mod error;
+mod freelist;
 mod heap;
-mod linear;
 mod slab;
 mod usage;
 mod util;
 
-// experimental sub-allocator for large transient allocations.
-#[cfg(feature = "freelist")]
-mod freelist;
-
 pub use {
     self::{allocator::*, block::MemoryBlock, config::*, error::*, usage::*},
     gpu_alloc_types::*,
